"use client";

import { useChat } from "ai/react";
import { Send } from "lucide-react";
import {
  ChatBubble,
  ChatBubbleAvatar,
  ChatBubbleMessage,
} from "@/components/ui/chat/chat-bubble";
import {
  ExpandableChatHeader,
  ExpandableChatBody,
  ExpandableChatFooter,
} from "@/components/ui/chat/expandable-chat";
import { Button } from "@/components/ui/button";
import { ChatInput } from "@/components/ui/chat/chat-input";
import { ChatMessageList } from "@/components/ui/chat/chat-message-list";

export default function Chat() {
  const { messages, input, handleInputChange, handleSubmit } = useChat();
  return (
    <div className="h-full w-full flex flex-col border sm:rounded-lg shadow-md overflow-hidden transition-all duration-200 ease-out">
      <ExpandableChatHeader className="flex-col text-center justify-center border-[#3e4452] py-3">
        <h1 className="text-xl font-semibold">Chat with AI Assistant ✨</h1>
      </ExpandableChatHeader>
      <ExpandableChatBody>
        <ChatMessageList>
          {messages.map((message, index) => (
            <ChatBubble key={index} layout="ai">
              <ChatBubbleAvatar
                src={message.role === "user" ? "/default.svg" : "/ai.svg"}
                fallback={message.role === "user" ? "US" : "AI"}
              />
              <ChatBubbleMessage layout="ai" className="border-[#3e4452]">
                {message.content}
              </ChatBubbleMessage>
            </ChatBubble>
          ))}
        </ChatMessageList>
      </ExpandableChatBody>
      <ExpandableChatFooter className="border-[#3e4452]">
        <form onSubmit={handleSubmit}>
          <div className="flex items-center justify-between gap-2">
            <ChatInput
              value={input}
              onChange={handleInputChange}
              className="bg-[#3e4452]"
            />
            <Button type="submit" size="icon">
              <Send className="size-4" />
            </Button>
          </div>
        </form>
      </ExpandableChatFooter>
    </div>
  );
}
